pub enum RunCommand {
RequestModel {
turn_id: TurnId,
step: u32,
context: ContextPack,
},
AwaitApproval {
call_id: ToolCallId,
reason: String,
},
ExecuteTool {
call: ToolCall,
},
}Expand description
Host command requested by the run state machine.
Variants
RequestModel
Ask the host to make a model request.
Fields

context: ContextPackValidated context to submit to the model provider.
AwaitApproval
Ask the host to obtain approval for a tool call.
Fields

call_id: ToolCallIdPending call requiring an approval decision.
ExecuteTool
Ask the host to execute a validated tool call.